#
# spec file for package nova
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           nova
Version:        3.11.2
Release:        1.1
Summary:        Find outdated or deprecated Helm charts running in your cluster
License:        Apache-2.0
URL:            https://github.com/FairwindsOps/nova
Source:         nova-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.19

# found conflict of nova-3.4.0-1.1.x86_64 with python3-novaclient-17.6.0-1.2.noarch
#   /usr/bin/nova
Conflicts:      python3-novaclient

%description
Nova scans your cluster for installed Helm charts, then cross-checks them against all known Helm repositories. If it finds an updated version of the chart you're using, or notices your current version is deprecated, it will let you know.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%setup -q
%setup -q -T -D -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.version=%{version} -X main.commit=v%{version}"

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Thu Jan  9 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.2:
  * feat: add stars field to ArtifactHub package structs and update
    scoring logic (#355)
* Sat Dec 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.11.1:
  * update preferred repo list (#352)
  * upgrade modules and docker base image (#351)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.11:
  * feat: kubeconfig path flag (#329)
* Fri Sep 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.10.2:
  * Bumped Go to 1.22.7 for fixing vulnerabilities (#335)
  * Bump alpine from 3.19 to 3.20 (#313)
  * Managed by Terraform
* Mon Aug 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.10.1:
  * INSIGHTS-247 Fix CVE-2024-41110 vulnerability for nova (#330)
* Thu Aug  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.10.0:
  * INSIGHTS-229 Fix nova vulnerability CVE-2024-41110 (#328)
  * docs: update documentation from template (#322)
  * Managed by Terraform
* Wed May  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.9.0:
  * Bumped golang.org/x/net to v0.17.0 to fix HIGH vulnerabilities
    (#300)
* Thu Mar 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.8.0:
  * FWI-5853 - Add kubeVersion field nova results (#299)
  * Added ignore_list_functionality (#252)
  * Update guide.md (#239)
  * Remove old install instructions (#238)
  * removed depracted ioutil references (#248)
* Thu Jul 27 2023 kastl@b1-systems.de
- Update to version 3.7.0:
  * Bump k8s.io/client-go from 0.27.2 to 0.27.3 (#229)
  * Allow custom timeout when fetching container tags (#235)
  * Update quickstart.md (#228)
  * Bump github.com/spf13/viper from 1.15.0 to 1.16.0 (#226)
  * Bump github.com/stretchr/testify from 1.8.3 to 1.8.4 (#227)
* Wed May 31 2023 kastl@b1-systems.de
- Update to version 3.6.5:
  * udpate dependencies and CI tools (#225)
  * Bump alpine from 3.17 to 3.18 (#221)
* Mon May 15 2023 kastl@b1-systems.de
- Update to version 3.6.4:
  * Document the use of private repostories more explicitly (#222)
* Wed May 10 2023 kastl@b1-systems.de
- Update to version 3.6.3:
  * Use new ArtifactHub cached API (#217)
  * remove experimental features in CI (#211)
* Wed Apr  5 2023 kastl@b1-systems.de
- Update to version 3.6.2:
  * update alpine and go mod (#210)
  * Update documentation from template (#209)
  * Update documentation from template (#202)
- add shell completion subpackages
- fix broken version display
- BuildRequire go1.19
- revert change to _service file, as releases are made without the
  leading "v" again...
* Sun Feb 12 2023 kastl@b1-systems.de
- Update to version 3.6.2:
  * Update alpine (#197)
- change _service file, as latest release is v3.6.2 (with a leading
  "v"), not sure if this will stay this way...
* Fri Feb 10 2023 kastl@b1-systems.de
- Update to version 3.6.1:
  * update go modules (#196) (bsc#1208095, CVE-2023-25165)
  * Add weekly and daily to unvalid releases (#187)
* Thu Jan  5 2023 kastl@b1-systems.de
- Update to version 3.6.0:
  * Update documentation from template (#188)
  * installation.md: complete asdf installation (#182)
  * Sc/rd 71 add plg links (#186)
  * Managed by Terraform
* Wed Dec 21 2022 kastl@b1-systems.de
- Update to version 3.5.0:
  * update dependencies and fix tests (#185)
  * Allowing filtering by namespace (#177)
  * Bump k8s.io/client-go from 0.24.2 to 0.25.4 (#174)
  * Bump alpine from 3.16 to 3.17 (#178)
  * Update dependencies + `nova find --containers` bug fix from PR #167 (#176)
* Wed Nov 16 2022 kastl@b1-systems.de
- Update to version 3.4.2:
  * Revert "update dependencies (#167)" (#175)
* Wed Nov 16 2022 kastl@b1-systems.de
- Update to version 3.4.1:
  * update dependencies (#167)
  * Update documentation from template (#161)
  * Managed by Terraform
* Fri Sep 16 2022 kastl@b1-systems.de
- Update to version 3.4.0:
  * add `--helm` flag to `find` command (#154)
* Thu Sep 15 2022 kastl@b1-systems.de
- Update to version 3.3.2:
  * update dependencies (#153)
* Tue Sep 13 2022 kastl@b1-systems.de
- Update to version 3.3.1:
  * Bump helm.sh/helm/v3 from 3.9.3 to 3.9.4 (#148)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 3.3.0:
  * update alpine (#144)
  * Bump k8s.io/api from 0.24.2 to 0.24.4 (#142)
  * Bump k8s.io/klog/v2 from 2.70.0 to 2.70.1 (#129)
  * Bump github.com/stretchr/testify from 1.7.2 to 1.8.0 (#127)
  * update example command (#133)
  * Bump helm.sh/helm/v3 from 3.9.0 to 3.9.3 (#138)
  * Bump alpine from 3.16.0 to 3.16.2 (#139)
  * Use oss-docs orb to publish docs (#128)
  * Added format flag option and enable file output to be CSV (#120)
  * Update dependencies (#126)
* Sat Jun  4 2022 kastl@b1-systems.de
- Update to version 3.2.0:
  * add flag --show-old to only charts not on the latest version (#111)
  * Bump alpine from 3.15 to 3.16.0 (#119)
  * Replace klog.Fatal with Klog.Error and os.Exit(1) (#116)
  * attempt to fix #106 by moving mutex lock (#115)
  * Update dependencies (#107)
* Sat May 14 2022 kastl@b1-systems.de
- Update to version 3.1.0:
  * container scanning implementation (#95)
  * Fix license headers (#92)
  * updated dependencies (#90)
* Mon Feb 21 2022 kastl@b1-systems.de
- Update to version 3.0.2:
  * Updating all dependencies (#82)
  * Add back --url functionality and new --poll-artifacthub in lieu of --poll-helm-hub (#74)
* Wed Feb 16 2022 kastl@b1-systems.de
- Update to version 3.0.1:
  * Added certificates in scratch base image: (#70)
  * Update documentation from template (#73)
* Wed Feb  9 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go1.17, as stated in the go.mod file
* Wed Feb  9 2022 kastl@b1-systems.de
- Update to version 3.0.0:
  * Add User-Agent header for Artifacthub requests (#68)
  * [RD-24] Utilize ArtifactHub instead of helm-hub (#61)
* Wed Jan 26 2022 Johannes Kastl <kastl@b1-systems.de>
- add Conflicts for python3-novaclient
* Wed Jan 26 2022 kastl@b1-systems.de
- Update to version 2.4.0:
  * Update build and release process (#65)
  * Delete .github/ISSUE_TEMPLATE/bug_report.md
  * Delete .github/ISSUE_TEMPLATE/bug.yaml
  * Delete .github/ISSUE_TEMPLATE/bug_report.md
  * Delete .github/stale.yml
  * Managed by Terraform
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 2.3.4:
  * Deprecate helm 2 support (#60)
  * Managed by Terraform
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 2.3.3:
  * [goreleaser] Support m1 mac (#59)
  * Update documentation from template (#56)
  * Update README.md (#51)
  * Update documentation from template (#46)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 2.3.2:
  * add banner (#44)
  * Update README.md (#43)
  * remove codecov (#41)
  * Managed by Terraform
  * Update documentation from template (#40)
* Wed May 26 2021 Johannes Kastl <kastl@b1-systems.de>
- initial version of package nova
